CA25_Cl03.html
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Panoramic views |
clickAndWait | link=Añadir panoramic view |
type | id_name | Nuevo
type | id_external_url | esto es un error
clickAndWait | _continue |
verifyTextPresent | Introduzca una URL válida. |
verifyTextPresent | exact:Url: |
clickAndWait | link=Terminar sesión |